@@ -356,7 +356,7 @@ ges_track_element_class_init (GESTrackElementClass * klass)
    */
   properties[PROP_ACTIVE] =
       g_param_spec_boolean ("active", "Active", "Use object in output", TRUE,
-      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_ACTIVE,
       properties[PROP_ACTIVE]);
 
@@ -371,7 +371,7 @@ ges_track_element_class_init (GESTrackElementClass * klass)
   properties[PROP_TRACK_TYPE] = g_param_spec_flags ("track-type", "Track Type",
       "The track type of the object", GES_TYPE_TRACK_TYPE,
       GES_TRACK_TYPE_UNKNOWN, G_PARAM_READWRITE | G_PARAM_CONSTRUCT |
-      G_PARAM_EXPLICIT_NOTIFY);
+      G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_TRACK_TYPE,
       properties[PROP_TRACK_TYPE]);
 
@@ -382,7 +382,8 @@ ges_track_element_class_init (GESTrackElementClass * klass)
    * belong to a track.
    */
   properties[PROP_TRACK] = g_param_spec_object ("track", "Track",
-      "The track the object is in", GES_TYPE_TRACK, G_PARAM_READABLE);
+      "The track the object is in", GES_TYPE_TRACK,
+      G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_TRACK,
       properties[PROP_TRACK]);
 
@@ -429,7 +430,7 @@ ges_track_element_class_init (GESTrackElementClass * klass)
   properties[PROP_HAS_INTERNAL_SOURCE] =
       g_param_spec_boolean ("has-internal-source", "Has Internal Source",
       "Whether the element has some internal source of stream data", FALSE,
-      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_HAS_INTERNAL_SOURCE,
       properties[PROP_HAS_INTERNAL_SOURCE]);
 
@@ -452,7 +453,7 @@ ges_track_element_class_init (GESTrackElementClass * klass)
       g_param_spec_boolean ("auto-clamp-control-sources",
       "Auto-Clamp Control Sources", "Whether to automatically update the "
       "control sources with a change in in-point or out-point", TRUE,
-      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class,
       PROP_AUTO_CLAMP_CONTROL_SOURCES,
       properties[PROP_AUTO_CLAMP_CONTROL_SOURCES]);
@@ -1171,8 +1172,11 @@ ges_track_element_add_children_props (GESTrackElement * self,
       case GST_ITERATOR_OK:
       {
         GstElement *child = g_value_get_object (&item);
-        ges_track_element_add_child_props (self, child, wanted_categories,
-            blacklist, whitelist);
+
+        if (!g_str_has_prefix (GST_OBJECT_NAME (child), "___ges__")) {
+          ges_track_element_add_child_props (self, child, wanted_categories,
+              blacklist, whitelist);
+        }
         g_value_reset (&item);
         break;
       }
@@ -1635,6 +1639,9 @@ ges_track_element_copy_properties (GESTimelineElement * element,
     g_value_unset (&val);
   }
 
+  for (n = 0; n < n_specs; ++n) {
+    g_param_spec_unref (specs[n]);
+  }
   g_free (specs);
 }
 
@@ -1776,6 +1783,9 @@ ges_track_element_copy_bindings (GESTrackElement * element,
     gst_object_unref (new_source);
   }
 
+  for (n = 0; n < n_specs; ++n) {
+    g_param_spec_unref (specs[n]);
+  }
   g_free (specs);
 }
 
@@ -1927,7 +1937,14 @@ ges_track_element_set_control_source (GESTrackElement * object,
     binding = gst_direct_control_binding_new (GST_OBJECT (element),
         property_name, source);
 
-  gst_object_add_control_binding (GST_OBJECT (element), binding);
+  ret = gst_object_add_control_binding (GST_OBJECT (element), binding);
+  if (!ret) {
+    GST_ERROR_OBJECT (object, "Could not add control binding");
+    gst_object_unref (binding);
+
+    goto done;
+  }
+
   /* FIXME: maybe we should force the
    * "ChildTypeName:property-name"
    * format convention for child property names in bindings_hashtable.
