@@ -110,6 +110,7 @@ ges_uri_clip_set_property (GObject * object, guint property_id,
 
   switch (property_id) {
     case PROP_URI:
+      /* G_PARAM_CONSTRUCT_ONLY */
       ges_uri_clip_set_uri (uriclip, g_value_dup_string (value));
       break;
     case PROP_MUTE:
@@ -156,7 +157,7 @@ ges_uri_clip_class_init (GESUriClipClass * klass)
    */
   g_object_class_install_property (object_class, PROP_URI,
       g_param_spec_string ("uri", "URI", "uri of the resource", NULL,
-          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
   /**
    * GESUriClip:mute:
@@ -165,7 +166,8 @@ ges_uri_clip_class_init (GESUriClipClass * klass)
    */
   g_object_class_install_property (object_class, PROP_MUTE,
       g_param_spec_boolean ("mute", "Mute", "Mute audio track",
-          FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+          FALSE,
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
   /**
    * GESUriClip:is-image:
@@ -176,7 +178,8 @@ ges_uri_clip_class_init (GESUriClipClass * klass)
   g_object_class_install_property (object_class, PROP_IS_IMAGE,
       g_param_spec_boolean ("is-image", "Is still image",
           "Whether the clip represents a still image or not",
-          FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+          FALSE,
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
   /* Redefine the supported formats property so the default value is UNKNOWN
    * and not AUDIO | VIDEO */
@@ -184,7 +187,7 @@ ges_uri_clip_class_init (GESUriClipClass * klass)
       g_param_spec_flags ("supported-formats",
           "Supported formats", "Formats supported by the file",
           GES_TYPE_TRACK_TYPE, GES_TRACK_TYPE_UNKNOWN,
-          G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+          G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS));
 
   element_class->set_max_duration = uri_clip_set_max_duration;
 
@@ -192,11 +195,13 @@ ges_uri_clip_class_init (GESUriClipClass * klass)
 }
 
 static gchar *
-extractable_check_id (GType type, const gchar * id)
+extractable_check_id (GType type, const gchar * id, GError ** error)
 {
   if (gst_uri_is_valid (id))
     return g_strdup (id);
 
+  g_set_error (error, GES_ERROR, GES_ERROR_ASSET_WRONG_ID, "URI %s is invalid",
+      id);
   return NULL;
 }
 
@@ -442,10 +447,9 @@ static void
 ges_extractable_interface_init (GESExtractableInterface * iface)
 {
   iface->asset_type = GES_TYPE_URI_CLIP_ASSET;
-  iface->check_id = (GESExtractableCheckId) extractable_check_id;
+  iface->check_id = extractable_check_id;
   iface->get_parameters_from_id = extractable_get_parameters_from_id;
   iface->get_id = extractable_get_id;
-  iface->get_id = extractable_get_id;
   iface->can_update_asset = TRUE;
   iface->set_asset_full = extractable_set_asset;
 }
