@@ -122,6 +122,25 @@ gst_compositor_operator_get_type_and_default_value (int *default_operator_value)
   return operator_gtype;
 }
 
+static GstElement *
+get_last_time_effect_filter (GstFramePositioner * self)
+{
+  if (!self->track_source) {
+    GST_DEBUG_OBJECT (self, "No track src");
+    return FALSE;
+  }
+
+  GESTimelineElement *parent = GES_TIMELINE_ELEMENT_PARENT (self->track_source);
+
+  if (!parent || !GES_IS_CLIP (parent)) {
+    GST_DEBUG_OBJECT (self, "Not in a clip");
+    return NULL;
+  }
+
+  GESTrack *track = ges_track_element_get_track (self->track_source);
+  return ges_clip_get_last_time_effect_filter (GES_CLIP (parent), track);
+}
+
 static gboolean
 scales_downstream (GstFramePositioner * self)
 {
@@ -324,10 +343,6 @@ gst_frame_positioner_update_properties (GstFramePositioner * pos,
         pos->track_width, "height", G_TYPE_INT, pos->track_height, NULL);
   }
 
-  if (pos->fps_n != -1)
-    gst_caps_set_simple (caps, "framerate", GST_TYPE_FRACTION, pos->fps_n,
-        pos->fps_d, NULL);
-
   if (pos->par_n != -1)
     gst_caps_set_simple (caps, "pixel-aspect-ratio", GST_TYPE_FRACTION,
         pos->par_n, pos->par_d, NULL);
@@ -373,6 +388,26 @@ done:
         "height", G_TYPE_INT, pos->natural_height, NULL);
   }
 
+  if (pos->fps_n != -1) {
+    GstElement *timeffect_capsfilter = get_last_time_effect_filter (pos);
+
+    if (timeffect_capsfilter) {
+      GstCaps *timeffect_caps =
+          gst_caps_new_simple ("video/x-raw", "framerate", GST_TYPE_FRACTION,
+          pos->fps_n, pos->fps_d, NULL);
+      gst_caps_set_features_simple (timeffect_caps,
+          gst_caps_features_new_any ());
+
+      GST_DEBUG_OBJECT (pos,
+          "Setting framerate on source last timne effect capsfilter");
+      g_object_set (timeffect_capsfilter, "caps", timeffect_caps, NULL);
+    } else {
+      GST_DEBUG_OBJECT (pos, "Setting framerate on source capsfilter");
+      gst_caps_set_simple (caps, "framerate", GST_TYPE_FRACTION, pos->fps_n,
+          pos->fps_d, NULL);
+    }
+  }
+
   GST_DEBUG_OBJECT (pos, "setting caps %" GST_PTR_FORMAT, caps);
 
   g_object_set (pos->capsfilter, "caps", caps, NULL);
@@ -508,6 +543,37 @@ gst_frame_positioner_dispose (GObject * object)
   G_OBJECT_CLASS (gst_frame_positioner_parent_class)->dispose (object);
 }
 
+static GstStateChangeReturn
+gst_frame_positioner_change_state (GstElement * element,
+    GstStateChange transition)
+{
+  GstFramePositioner *framepositioner = GST_FRAME_POSITIONNER (element);
+  if (transition == GST_STATE_CHANGE_READY_TO_PAUSED) {
+    gboolean track_mixing = TRUE;
+
+    if (framepositioner->current_track)
+      track_mixing = ges_track_get_mixing (framepositioner->current_track);
+    gst_frame_positioner_update_properties (framepositioner, track_mixing, 0,
+        0);
+  }
+
+  GstStateChangeReturn res =
+      GST_ELEMENT_CLASS (gst_frame_positioner_parent_class)->change_state
+      (element, transition);
+
+  if (transition == GST_STATE_CHANGE_PAUSED_TO_READY) {
+    GstElement *timeffect_capsfilter =
+        get_last_time_effect_filter (framepositioner);
+
+    if (timeffect_capsfilter) {
+      g_object_set (timeffect_capsfilter, "caps", NULL, NULL);
+    }
+  }
+
+  return res;
+}
+
+
 static void
 gst_frame_positioner_class_init (GstFramePositionerClass * klass)
 {
@@ -518,6 +584,7 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   guint n_pspecs = PROP_LAST;
 
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+  GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
   GstBaseTransformClass *base_transform_class =
       GST_BASE_TRANSFORM_CLASS (klass);
 
@@ -532,6 +599,7 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   gobject_class->set_property = gst_frame_positioner_set_property;
   gobject_class->get_property = gst_frame_positioner_get_property;
   gobject_class->dispose = gst_frame_positioner_dispose;
+  element_class->change_state = gst_frame_positioner_change_state;
   base_transform_class->transform_ip =
       GST_DEBUG_FUNCPTR (gst_frame_positioner_transform_ip);
 
@@ -542,7 +610,7 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
    */
   properties[PROP_ALPHA] =
       g_param_spec_double ("alpha", "alpha", "alpha of the stream", 0.0, 1.0,
-      1.0, G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE);
+      1.0, G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS);
 
   /**
    * gstframepositioner:posx:
@@ -552,7 +620,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_POSX] =
       g_param_spec_int ("posx", "posx", "x position of the stream",
       MIN_PIXELS, MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
   /**
    * gstframepositioner:fposx:
@@ -562,7 +631,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_FPOSX] =
       g_param_spec_float ("fposx", "fposx", "x position of the stream in float",
       MIN_PIXELS, MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
   /**
    * gstframepositioner:posy:
@@ -572,7 +642,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_POSY] =
       g_param_spec_int ("posy", "posy", "y position of the stream",
       MIN_PIXELS, MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
 
   /**
@@ -583,7 +654,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_FPOSY] =
       g_param_spec_float ("fposy", "fposy", "y position of the stream in float",
       MIN_PIXELS, MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
   /**
    * gstframepositioner:zorder:
@@ -591,8 +663,12 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
    * The desired z order for the stream.
    */
   properties[PROP_ZORDER] =
-      g_param_spec_uint ("zorder", "zorder", "z order of the stream", 0,
-      G_MAXUINT, 0, G_PARAM_READWRITE);
+      g_param_spec_uint ("zorder", "zorder",
+      "z order of the stream.\n\n"
+      "**WARNING**: Setting it manually overrides the "
+      "#GESLayer:priority and should be used very carefully", 0,
+      G_MAXUINT, 0,
+      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | GST_PARAM_CONTROLLABLE);
 
   /**
    * gesframepositioner:width:
@@ -603,7 +679,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_WIDTH] =
       g_param_spec_int ("width", "width", "width of the source", 0,
       MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
   /**
    * gesframepositioner:fwidth:
@@ -614,7 +691,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_FWIDTH] =
       g_param_spec_float ("fwidth", "fwidth", "width of the source in float", 0,
       MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
   /**
    * gesframepositioner:height:
@@ -625,7 +703,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_HEIGHT] =
       g_param_spec_int ("height", "height", "height of the source", 0,
       MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
   /**
    * gesframepositioner:fheight:
@@ -636,7 +715,8 @@ gst_frame_positioner_class_init (GstFramePositionerClass * klass)
   properties[PROP_FHEIGHT] =
       g_param_spec_float ("fheight", "fheight", "height of the source in float",
       0, MAX_PIXELS, 0,
-      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION);
+      G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_LAX_VALIDATION |
+      G_PARAM_STATIC_STRINGS);
 
   /**
    * gesframepositioner:operator:
